<?php
/**
 * Theme Setup
 */
add_action('after_setup_theme', 'theme_setup');
if (! function_exists('theme_setup')):
function theme_setup() {
	global $wp_roles;

	// This theme styles the visual editor with editor-style.pps to match the theme style.
	add_editor_style();

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu('primary','Primary Menu');
	register_nav_menu('footer',	'Footer Menu');
}
endif;

/**
 * Remove YOAST SEO metabox on specific post types
 */
add_action('add_meta_boxes', 'remove_yoast_metabox',11);
function remove_yoast_metabox(){
    remove_meta_box('wpseo_meta', 'slide', 'normal');
}

/**
 * Options Page
 */
/*
// Does not work in v5
add_filter('acf/options_page/settings', 'my_acf_options_page_settings');
function my_acf_options_page_settings($settings)
{
	//$settings['title'] = 'Global';
	$settings['pages'] = array('General');
	return $settings;
}
*/
if( function_exists('acf_add_options_page') ) {
	acf_add_options_page(array(
		'page_title' 	=> 'General',
		'menu_title'	=> 'Options',
		'menu_slug' 	=> 'options',
		'capability'	=> 'edit_posts',
		'redirect'	=> false
	));
}


/**
 *Custom Styles for TinyMCE
 */
add_filter( 'mce_buttons_2', 'theme_mce_buttons_2' );
function theme_mce_buttons_2( $buttons ) {
    array_unshift( $buttons, 'styleselect' );
    return $buttons;
}

add_filter( 'tiny_mce_before_init', 'theme_mce_before_init' );
function theme_mce_before_init( $settings ) {

    $style_formats = array(
    	array(
    		'title' => 'Button',
    		'selector' => 'a',
    		'classes' => 'button'
    	),
    	array(
    		'title' => 'Intro',
    		'selector' => 'p',
    		'classes' => 'intro'
    	)
    );

    $settings['style_formats'] = json_encode( $style_formats );

    return $settings;

}

// Remove Multilingual Content Setup metabox
add_action('admin_head', 'disable_icl_metabox');
function disable_icl_metabox() {
	if (get_current_user_id() != 1) {
		$screen = get_current_screen();
    	remove_meta_box('icl_div_config',$screen->post_type,'normal');
	}
}

// Add slug to menu
add_filter( 'nav_menu_css_class', 'my_special_nav_class', 10, 2 );
function my_special_nav_class( $classes, $item ) {
	if( 'page' == $item->object ){
		$page = get_post( $item->object_id );
		$classes[] = 'menu-item-' . $page->post_name;
	}

	if( 'category' == $item->object ){
        $category = get_category( $item->object_id );
        $classes[] = 'menu-item-' . $category->slug;
    }

	return $classes;
}

// Removes ul class from wp_nav_menu
// add_filter( 'wp_nav_menu', 'remove_ul' );
// function remove_ul ( $menu ){
//     return preg_replace( array( '#^<ul[^>]*>#', '#</ul>$#' ), '', $menu );
// }

add_filter( 'wp_mail_from_name', 'custom_wp_mail_from_name' );
function custom_wp_mail_from_name( $original_email_from )
{
        return 'A Total Concept';
}

add_filter( 'wp_mail_from', 'custom_wp_mail_from' );
function custom_wp_mail_from( $original_email_address )
{
        //Make sure the email is from the same domain 
        //as your website to avoid being marked as spam.
        return 'noreply@atotalconcept.com.au';
}

add_filter( 'the_content_more_link', 'modify_read_more_link' );
	function modify_read_more_link() {
	return '<a class="more-link" href="' . get_permalink() . '">READ MORE ></a>';
}

add_filter('nav_menu_css_class', 'current_type_nav_class', 10, 2 );
function current_type_nav_class($classes, $item) {
    $post_type = get_query_var('post_type');
    if ($post_type == 'project' && $item->title == 'Projects') {
        array_push($classes, 'current-menu-item');
    };
    return $classes;
}